From khali@linux-fr.org Thu Jul 28 14:15:19 2005
Date: Thu, 28 Jul 2005 23:14:59 +0200
From: Jean Delvare <khali@linux-fr.org>
To: Greg KH <greg@kroah.com>, "Mark M. Hoffman" <mhoffman@lightlink.com>
Subject: hwmon: move SENSORS_LIMIT to hwmon.h
Message-Id: <20050728231459.3c3585e4.khali@linux-fr.org>


Move SENSORS_LIMIT from i2c-sensor.h to hwmon.h, as it is in no way
related to i2c.

Signed-off-by: Jean Delvare <khali@linux-fr.org>
Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>


---
 drivers/hwmon/lm75.h       |    2 +-
 include/linux/hwmon.h      |   11 +++++++++++
 include/linux/i2c-sensor.h |   12 ------------
 3 files changed, 12 insertions(+), 13 deletions(-)

--- gregkh-2.6.orig/drivers/hwmon/lm75.h	2005-08-02 13:41:27.000000000 -0700
+++ gregkh-2.6/drivers/hwmon/lm75.h	2005-08-08 14:38:47.000000000 -0700
@@ -25,7 +25,7 @@
     which contains this code, we don't worry about the wasted space.
 */
 
-#include <linux/i2c-sensor.h>
+#include <linux/hwmon.h>
 
 /* straight from the datasheet */
 #define LM75_TEMP_MIN (-55000)
--- gregkh-2.6.orig/include/linux/hwmon.h	2005-08-08 09:58:22.000000000 -0700
+++ gregkh-2.6/include/linux/hwmon.h	2005-08-08 14:38:47.000000000 -0700
@@ -20,5 +20,16 @@
 
 void hwmon_device_unregister(struct class_device *cdev);
 
+/* Scale user input to sensible values */
+static inline int SENSORS_LIMIT(long value, long low, long high)
+{
+	if (value < low)
+		return low;
+	else if (value > high)
+		return high;
+	else
+		return value;
+}
+
 #endif
 
--- gregkh-2.6.orig/include/linux/i2c-sensor.h	2005-08-08 09:58:22.000000000 -0700
+++ gregkh-2.6/include/linux/i2c-sensor.h	2005-08-08 14:38:47.000000000 -0700
@@ -242,16 +242,4 @@
 		      struct i2c_address_data *address_data,
 		      int (*found_proc) (struct i2c_adapter *, int, int));
 
-
-/* This macro is used to scale user-input to sensible values in almost all
-   chip drivers. */
-static inline int SENSORS_LIMIT(long value, long low, long high)
-{
-	if (value < low)
-		return low;
-	else if (value > high)
-		return high;
-	else
-		return value;
-}
 #endif				/* def _LINUX_I2C_SENSOR_H */
